::: polaris.dataset.converters.Converter
    options:
        filters: ["!^_"]

---


::: polaris.dataset.converters.SDFConverter
    options:
        filters: ["!^_"]

---

::: polaris.dataset.converters.ZarrConverter
    options:
        filters: ["!^_"]

---
